Class: Decidim::Accountability::HighlightedResultsCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::Accountability::HighlightedResultsCell
- Defined in:
- app/cells/decidim/accountability/highlighted_results_cell.rb
Overview
This cell renders the highlighted results for a given participatory
space. It is intended to be used in the participatory_space_highlighted_elements
view hook.