Class: Decidim::Accountability::Admin::CreateMilestone
- Inherits:
-
Commands::CreateResource
- Object
- Commands::CreateResource
- Decidim::Accountability::Admin::CreateMilestone
- Defined in:
- app/commands/decidim/accountability/admin/create_milestone.rb
Overview
This command is executed when the user creates a Milestone for a Result from the admin panel.